<?php
/*******************************************************************************
*    myMVC - Model-View-Controller for PHP                                     *
*    Copyright (C) 2012 Luca Bertoncello                                       *
*    Hartigstrasse, 12 - 01127 Dresden Deutschland                             *
*    E-Mail: lucabert@lucabert.de, lucabert@lucabert.com                       *
*    http://www.lucabert.de/  http://www.lucabert.com/                         *
*                                                                              *
*    This program is free software; you can redistribute it and/or modify      *
*    it under the terms of the GNU Lesser General Public License as published  *
*    by the Free Software Foundation; version 2.1 of the License.              *
*                                                                              *
*    This program is distributed in the hope that it will be useful,           *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
*    GNU Lesser General Public License for more details.                       *
*                                                                              *
*    You should have received a copy of the GNU Lesser General Public License  *
*    along with this program; if not, write to the Free Software               *
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
*******************************************************************************/

/**
 * In order to load all myMVC-classes, we use an autoload function.
 * You can use your own function to load your classes, using spl_autoload_register
 * or just defining a __autoload() function, <b>before</b> including this file!
 */
spl_autoload_register('myMVC_autoload');

define("MYMVC_CURRENTVERSION",    '0.9.1-20120627');

/************************************************
 * Alert-types for ErrorHandlers
 ************************************************/
define("ALERT_SQL",               0);
define("ALERT_DEBUG",             1);
define("ALERT_WARNING",           2);
define("ALERT_CRITICAL",          3);

/************************************************
 * If not already specified, paths for error page
 ************************************************/
if(!defined('PAGE_ERROR'))
  define("PAGE_ERROR",            'http://'.$_SERVER['SERVER_NAME'].dirname($_SERVER['PHP_SELF']).'/../errors/syserror.php');

/************************************************
 * If not already specified, paths for error and
 * debug log file
 ************************************************/
if(!defined('LOG_FILE'))
  define("LOG_FILE",              "/tmp/mymvc.log");

/************************************************
 * Array with configuration data
 ************************************************/
$config = array();

$config['myMVC_PATH']             = dirname(__FILE__);

if(function_exists('posix_uname'))
{ // For Unix systems
  $uname = posix_uname();
  $config['nodeName']             = $uname['nodename'];
}
elseif(function_exists('php_uname'))
{ // For Unix systems, without POSIX extensions
  $config['nodeName']             = php_uname('n');
}
else
{ // Windows is not POSIX and we have to read the enviroment variables
  $config['nodeName']             = $_ENV['COMPUTERNAME'];
}

if(function_exists('posix_getpid'))
{ // For Unix systems
  $config['myPID']                = posix_getpid();
}
elseif(function_exists('getmypid'))
{ // For Unix systems, without POSIX extensions
  $config['myPID']                = getmypid();
}
else
{ // Windows has no PID, using a foo value
  $config['myPID']                = 1234;
}

/************************************************
 * SQL queries will be logged
 ************************************************/   
$config['SYSTEM']['DEBUG_SQL']    = false;
/************************************************
 * All logs from this level upwards will be logged
 ************************************************/   
$config['SYSTEM']['ALERT_LEVEL']  = ALERT_WARNING;

/************************************************
 * Date and time format
 ************************************************/   
$config['DATEFORMAT']             = _('d.m.y');
$config['TIMEFORMAT']             = _('H:i:s');
$config['DATETIMEFORMAT']         = _('d.m.y H:i:s');
$config['TIMEZONE']               = 'Europe/Berlin';

/************************************************
 * true if the page "system error" should be displayed
 ************************************************/   
$config['DISPLAY_SYSERROR']       = true;

/************************************************
 * Defaults for session
 * 
 * To use database session, define the following:
 * <code>
 * $config['SESSION_TYPE']           = DB_SESSION;
 * $config['SESSION_DB']             = array(
 *                                           'table'           => 'dbsession',
 *                                           'field_sid'       => 'sid',
 *                                           'field_data'      => 'data',
 *                                           'field_last_used' => 'last_used',
 *                                        );
 * </code>
 ************************************************/   
define("FILE_SESSION",            0);
define("DB_SESSION",              1);

$config['SESSION_LIFETIME']       = 28800;
$config['SESSION_USECOOKIES']     = 0;
$config['SESSION_TYPE']           = FILE_SESSION;

myMVC_ErrorHandler::setExceptionCatcher();

/**
 * Autoload function.
 * If the user tried to call a myMVC class
 * 
 * @param $class          Class to load
 */
function myMVC_autoload($class)
{
  global $config;

  if(strncmp($class, 'myMVC_', 6) == 0)
  {
    $className = $config['myMVC_PATH'].DIRECTORY_SEPARATOR.str_replace('_', DIRECTORY_SEPARATOR, $class).'.php';
    require_once $className;
  }
}

/**
 * If the user defined an own autoload function...
 */
if(function_exists('__autoload'))
  spl_autoload_register('__autoload');

/************************************************
 * Function get_called_class is just in PHP >= 5.3.0
 * available...
 * So here a rewrite of this function!
 ************************************************/   
if(!function_exists('get_called_class'))
{
  function get_called_class()
  {
    $bt = debug_backtrace();

    $class = $bt[1]['class'];
    for($n = -1, $l = 0; $l < count($bt); $l++)
      if($bt[$l]['type'] == '::' && $bt[$l]['class'] == $class)
        $n = $l;
    // Reads the file and get the function call at the line X
    // So we can get the class name
    $lines = file($bt[$n]['file']);
    preg_match_all('/([a-zA-Z0-9\_]+)::'.$bt[$n]['function'].'/',
        $lines[$bt[$n]['line'] - 1],
        $matches);

    return $matches[1][0];
  }
}
?>
